@@ -17,9 +17,9 @@ class PickUp(object):
         if self.date is not None:
             self.date = datetime.fromtimestamp(int(self.date) / 1000).strftime("%Y-%m-%d")
         if self.start_time is not None:
-            self.start_time = datetime.fromtimestamp(int(self.start_time) / 1000)
+            self.start_time = datetime.fromtimestamp(int(self.start_time) / 1000).strftime("%H:%M")
         if self.end_time is not None:
-            self.end_time = datetime.fromtimestamp(int(self.end_time) / 1000)
+            self.end_time = datetime.fromtimestamp(int(self.end_time) / 1000).strftime("%H:%M")
         if self.cut_off_date is not None:
             self.cut_off_date = datetime.fromtimestamp(int(self.cut_off_date) / 1000)
 
